window.Gleam.initSearch([{"doc":"html_parser","title":"html_parser","content":"# html_parser\n\n[![Package Version](https://img.shields.io/hexpm/v/html_parser)](https://hex.pm/packages/html_parser)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/html_parser/)\n\n`html_parser` is a simple library for parsing an HTML document. Use `html_parser.as_list` to parse the document\nas List of Elements. Use `html_parser.as_tree` to create a nested structure where Elements have children.\n\n- `StartElement`: HTML opening tag, like `&lt;div&gt;`\n- `EndElement`: HTML closing tag, like `&lt;/div&gt;`\n- `Content`: Non-HTML parts of the document inside tags (the &quot;hello&quot; in `&lt;div&gt;hello&lt;/div&gt;`)\n- `Attributes`: HTML attributes inside of a tag (`href` key and value in `&lt;a href=&quot;github.com&quot;&gt;`)\n\n```sh\ngleam add html_parser@1\n```\n```gleam\nimport html_parser\n\npub fn main() {\n  &quot;&lt;div&gt;&lt;div class=\\&quot;data\\&quot;&gt;Data!&lt;/div&gt;&lt;/div&gt;&quot;\n  |&gt; html_parser.as_list\n  |&gt; find_div\n  |&gt; io.debug\n}\n\n// find a starting div where class=data and the next element is Content\nfn find_div(in: List(html_parser.Element)) -&gt; String {\n  case in {\n    [] -&gt; &quot;Not found&quot;\n    [\n      html_parser.StartElement(&quot;div&quot;, [html_parser.Attribute(&quot;class&quot;, &quot;data&quot;)], _),\n      html_parser.Content(contents),\n      ..\n    ] -&gt; contents\n    [_, ..tail] -&gt; find_div(tail)\n  }\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/html_parser&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"html_parser","title":"Attribute","content":"pub type Attribute {\n  Attribute(key: String, value: String)\n}\n Attribute is an HTML attribute key-value pair\nAttribute(key: String, value: String)\n\n\nSynonyms:\nhtml_parser.Attribute\nhtml_parser Attribute","url":"html_parser.html#Attribute"},{"doc":"html_parser","title":"Element","content":"pub type Element {\n  EmptyElement\n  StartElement(\n    name: String,\n    attributes: List(Attribute),\n    children: List(Element),\n  )\n  EndElement(name: String)\n  Content(String)\n}\n Element is a part of an HTML document\nEmptyElement\n\n\nStartElement(\n  name: String,\n  attributes: List(Attribute),\n  children: List(Element),\n)\n StartElement is an opening tag like &lt;div&gt; and can have Attributes and child Elements\n\nEndElement(name: String)\n EndElement just has a name and signals the end of a block\n\nContent(String)\n Content is non-HTML parts of the document in-between StartElement and\n EndElement (the &quot;hello&quot; in `&lt;div&gt;hello&lt;/div&gt;`)\n\nSynonyms:\nhtml_parser.Element\nhtml_parser Element","url":"html_parser.html#Element"},{"doc":"html_parser","title":"as_list","content":"pub fn as_list(in: String) -&gt; List(Element)\n\nSynonyms:\nhtml_parser.as_list\nhtml_parser as_list","url":"html_parser.html#as_list"},{"doc":"html_parser","title":"as_tree","content":"pub fn as_tree(in: String) -&gt; Element\n\nSynonyms:\nhtml_parser.as_tree\nhtml_parser as_tree","url":"html_parser.html#as_tree"},{"doc":"html_parser","title":"get_attrs","content":"pub fn get_attrs(in: String) -&gt; #(List(Attribute), String)\n get the attributes for a StartElement and remaining String\nSynonyms:\nhtml_parser.get_attrs\nhtml_parser get_attrs","url":"html_parser.html#get_attrs"},{"doc":"html_parser","title":"get_first_element","content":"pub fn get_first_element(in: String) -&gt; #(Element, String)\n get the first Element and remaining String\nSynonyms:\nhtml_parser.get_first_element\nhtml_parser get_first_element","url":"html_parser.html#get_first_element"},{"doc":"html_parser","title":"html_parser","content":"","url":"html_parser.html"}]);